import { Logger } from './logger';
import { Helpers } from './helpers';
if (Helpers.isNode) {
}
export class Log {
    //#region singleton
    constructor() {
        this._logOnly = false;
        this._logModules = false;
        this.isDevelopmentMode = true;
        this.modeIsSet = false;
        this.fixedWidth = 0;
        this.instances = {};
        this.levels = [];
        this.modules = [];
    }
    static get instance() {
        if (!this._instance) {
            this._instance = new Log();
        }
        return this._instance;
    }
    static create(name, ...level) {
        return Log.instance.create(name, ...level);
    }
    //#region public api
    setProductionMode() {
        if (this.modeIsSet) {
            this.modeIsSet = false;
            throw '[ng2-logger] Production mode is already set';
        }
        else {
            this.modeIsSet = true;
            setTimeout(() => {
                if (this.modeIsSet && console !== void 0 && console.clear !== void 0) {
                    console.clear();
                    console.log = () => { };
                    console.error = () => { };
                    console.warn = () => { };
                    console.info = () => { };
                }
            });
            this.isDevelopmentMode = false;
        }
    }
    onlyModules(...modules) {
        if (this._logModules) {
            throw '[ng2-logger] You should use funcion onlyModules only once';
        }
        if (!this._logModules) {
            this._logModules = true;
        }
        if (modules.length === 0)
            return;
        this.modules = modules;
        // console.log('only log this', Log.modules)
        this.muteAllOtherModules();
    }
    onlyLevel(...level) {
        if (this._logOnly) {
            throw '[ng2-logger] You should use funcion onlyLevel only once';
        }
        if (!this._logOnly) {
            this._logOnly = true;
        }
        this.levels = Array.isArray(level) ? level : [level];
        for (const logName in this.instances) {
            if (this.instances.hasOwnProperty(logName)) {
                const element = this.instances[logName];
                element['allowed'] = this.levels;
            }
        }
    }
    //#endregion
    create(name, ...level) {
        let i;
        if (Array.isArray(this.levels) && this.levels.length > 0) {
            level = this.levels;
        }
        if (this.instances[name] === void 0) {
            i = new (Log.Logger)(name, getRandomColor(), this.isDevelopmentMode, level, this.isMutedModule(name), this.levels.length > 0 ? this.fixedWidth : void 0);
            this.instances[name] = i;
        }
        else {
            i = this.instances[name];
        }
        return i;
    }
    isMutedModule(moduleName) {
        if (this.modules.length == 0)
            return false;
        if (!Helpers.contain(this.modules, moduleName))
            return true;
        return false;
    }
    muteAllOtherModules() {
        for (var moduleName in this.instances) {
            if (!Helpers.contain(this.modules, moduleName))
                this.instances[moduleName].mute();
        }
    }
}
//#endregion
Log.Logger = Logger;
function getRandomColor() {
    let letters = '012345'.split('');
    let color = '#';
    color += letters[Math.round(Math.random() * 5)];
    letters = '0123456789ABCDEF'.split('');
    for (let i = 0; i < 5; i++) {
        color += letters[Math.round(Math.random() * 15)];
    }
    if (color === void 0) {
        return getRandomColor();
    }
    ;
    return color;
}
//# sourceMappingURL=log.js.map